Contributors Guide
==================

.. toctree::
   :maxdepth: 2

For developers
**************

* Use regular virtualenv or any other (no pre-defined preparations provided)

* Running tests::

    tox

* Building package::

    tox -e build

* Contributing: contact me through `Issues <https://github.com/pyctrl/izulu/issues>`__


Versioning
**********

`SemVer <http://semver.org/>`__ used for versioning.
For available versions see the repository
`tags <https://github.com/pyctrl/izulu/tags>`__
and `releases <https://github.com/pyctrl/izulu/releases>`__.
